@@ -10,8 +10,8 @@ from ansurr.functions import check_quiet_print
 def calc_secondary_structure(pdb,output_dir='',quiet=False):
 
     if platform == "linux" or platform == "linux2":
-        #with resources.path("ansurr.bin", "dssp.bin") as f:  # use this for the package
-        with resources.path("bin", "dssp.bin") as f: 
+        with resources.path("ansurr.bin", "dssp.bin") as f:  # use this for the package
+        #with resources.path("bin", "dssp.bin") as f: 
             dssp_file_path = f
 
     if not os.path.exists(output_dir):
